Links
+++++
* `Documentation <https://bruges.readthedocs.org/en/latest/>`_
* `Project page <http://agile-geoscience.github.com/bruges/>`_
* `Issue Tracker <https://github.com/agile-geoscience/bruges/issues/>`_
* `PyPi <http://pypi.python.org/pypi/bruges/>`_
* `Agile Geoscience <http://www.agilegeoscience.com>`_
